auditok, an AUDIo TOKenization tool — auditok 0.1.4 documentation

# auditok, an AUDIo TOKenization tool

auditok is an Audio Activity Detection tool that can process online data (read from an audio device or from standard input) as well as audio files. It can be used as a command line program and offers an easy to use API.

The latest version of this documentation can be found at Readthedocs.

## Requirements

auditok can be used with standard Python!

However if you want more features, the following packages are needed:

- Pydub : read audio files of popular audio formats (ogg, mp3, etc.) or extract audio from a video file
- PyAudio : read audio data from the microphone and play back detections
- matplotlib : plot audio signal and detections (see figures above)
- numpy : required by matplotlib. Also used for math operations instead of standard python if available
- Optionally, you can use sox or parecord for data acquisition and feed auditok using a pipe.

## Installation

    git clone https://github.com/amsehili/auditok.git
    cd auditok
    sudo python setup.py install

## Getting started

- Command-line Usage Guide
- API Tutorial

## API Reference

- auditok.core
  - Class summary
- auditok.util
  - Class summary
- auditok.io
  - Class summary
  - Function summary
- auditok.dataset

# Indices and tables

- Index
- Module Index
- Search Page